@@ -49,10 +49,11 @@ def str_to_range(range_str):
 # pylint: disable=C0103
 class bidict(dict):
     """
-    A simple bidirectional dictionary
+    A simple bidirectional dictionary, composed of two
+    ordinary dictionaries
     """
     def __init__(self, *args, **kwargs):
-        super(bidict, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.inverse = {}
         for key, value in self.items():
             self.inverse.setdefault(value, []).append(key)
@@ -60,11 +61,11 @@ class bidict(dict):
     def __setitem__(self, key, value):
         if key in self:
             self.inverse[self[key]].remove(key)
-        super(bidict, self).__setitem__(key, value)
+        super().__setitem__(key, value)
         self.inverse.setdefault(value, []).append(key)
 
     def __delitem__(self, key):
         self.inverse.setdefault(self[key], []).remove(key)
         if self[key] in self.inverse and not self.inverse[self[key]]:
             del self.inverse[self[key]]
-        super(bidict, self).__delitem__(key)
+        super().__delitem__(key)
