@@ -29,7 +29,7 @@ from decimal import Decimal
 
 from pyxperiment.controller import VisaInstrument
 from pyxperiment.controller.device_options import (
-    ValueDeviceOption, ListDeviceOption, TimeoutOption
+    ValueDeviceOption, ListDeviceOption, TimeoutControl
 )
 
 class RS8043PowerSource(VisaInstrument):
