@@ -27,18 +27,34 @@
 import random
 import time
 
-from pyxperiment.controller.device_options import ValueDeviceOption
+from pyxperiment.core.utils import bidict
+from pyxperiment.controller.device_options import ActionControl, ValueDeviceOption
 from pyxperiment.controller.instrument import Instrument
+from pyxperiment.controller.validation import StaticRangeValidator
 
 class TestDevice(Instrument):
 
     def __init__(self, rm, resource):
         super().__init__('')
+        del rm
         self.last_value = 0
         self.last_value2 = 0
-        self.options = []
+        self._rand_channels = 1
+        self.options = [
+            self.channels, self.reset
+        ]
         self.resource = resource if resource else 'Test address'
 
+    def _reset(self):
+        self.last_value = 0
+        self.last_value2 = 0
+
+    def get_channels_num(self):
+        return str(self._rand_channels)
+
+    def set_channels_num(self, value):
+        self._rand_channels = int(value)
+
     @staticmethod
     def driver_name():
         return 'Test'
@@ -63,12 +79,39 @@ class TestDevice(Instrument):
 
     def get_random(self):
         #time.sleep(0.1)
-        return str(random.triangular(-10, 10))
+        if self._rand_channels == 1:
+            return str(random.triangular(-10, 10))
+        return [str(random.triangular(-10, 10)) for i in range(self._rand_channels)]
 
-    def get_random2(self):
-        return [str(random.triangular(-10, 10)), str(random.triangular(-10, 10))]
+    channels = ValueDeviceOption(
+        'Random channels', None,
+        get_func=get_channels_num,
+        set_func=set_channels_num,
+        validator=StaticRangeValidator(1, 8, 1),
+        sweepable=False
+        )
 
-    value = ValueDeviceOption('Sweepable', 'V', get_value, set_value)
-    value2 = ValueDeviceOption('Measurable Up', 'V', get_value2)
-    rand = ValueDeviceOption('Measurable Random', 'V', get_random)
-    rand2 = ValueDeviceOption('Measurable Random 2D', 'V', get_random2, channels=2)
+    value = ValueDeviceOption(
+        'Sweepable', 'V', get_value, set_value
+        )
+    value2 = ValueDeviceOption(
+        'Measurable Up', 'V', get_value2
+        )
+    rand = ValueDeviceOption(
+        'Measurable Random', 'V', get_random, None, lambda self: int(self.get_channels_num())
+        )
+
+    reset = ActionControl(
+        'Reset', _reset
+    )
+
+    test_list_values = bidict({
+        '6 dB/oct':'1',
+        '12 dB/oct':'2',
+        '18 dB/oct':'3',
+        '24 dB/oct':'4',
+        '30 dB/oct':'5',
+        '36 dB/oct':'6',
+        '42 dB/oct':'7',
+        '48 dB/oct':'8'
+    })
